@@ -2,7 +2,7 @@ import importlib
 from IzVerifier.izspecs.containers.izclasses import IzClasses
 
 from IzVerifier.izspecs.izproperties import IzProperties
-from IzVerifier.izspecs.verifiers.dependencies import test_verify_all_dependencies
+from IzVerifier.izspecs.verifiers.dependencies import ConditionDependencyGraph
 from IzVerifier.izspecs.verifiers.seeker import Seeker
 from IzVerifier.izspecs.containers.constants import *
 from IzVerifier.exceptions.IzVerifierException import IzArgumentsException
@@ -31,18 +31,18 @@ class IzVerifier():
             'sources': [path1, path2, ...]      # Path(s) to associated source code roots.
         }
         """
-        validate_arguments(args)
+        _validate_arguments(args)
         self.reporter = Reporter()
         self.specifications = ['conditions', 'variables', 'strings']
         self.containers = {}
         self.sources = args.get('sources', [])
 
-        if args.has_key('pom'):
+        if 'pom' in args:
             self.properties = IzProperties(args['pom'])
         else:
             self.properties = None
         self.paths = IzPaths(args['specs_path'], args['resources_path'], self.properties)
-        self.fill_classes()
+        self._fill_classes()
         self.seeker = Seeker(self.paths)
 
     def verify_all(self, verbosity=0):
@@ -55,7 +55,6 @@ class IzVerifier():
             missing |= self.verify(specification, verbosity)
         return missing
 
-
     def verify(self, specification, verbosity=0):
         """
         Runs a verification on the given izpack spec: conditions, strings, variables, etc.
@@ -64,12 +63,12 @@ class IzVerifier():
         container = self.get_container(specification)
         defined = container.get_keys()
         crefs = self.find_code_references(specification)
-        srefs = self.find_spec_references(specification)
+        srefs = self.find_specification_references(specification)
 
-        self.load_references(crefs | srefs, container)
+        self._load_references(crefs | srefs, container)
 
-        cmissing = undefined(defined, crefs)
-        smissing = undefined(defined, srefs)
+        cmissing = _undefined(defined, crefs)
+        smissing = _undefined(defined, srefs)
 
         if verbosity > 0:
             self.reporter.report_test('undefined {0} referenced in code'.format(specification), cmissing)
@@ -77,24 +76,24 @@ class IzVerifier():
 
         return cmissing | smissing
 
-    def load_references(self, references, container):
+    def dependency_verification(self, verbosity=0, fail_on_undefined_vars=False):
         """
-        Load a container's referenced map with all detected references from source code and spec files.
+        Run a conditions dependency graph search.
         """
-        referenced = container.get_referenced()
-        for ref in references:
-            if referenced.has_key(ref[0]):
-                referenced[ref[0]].add(ref[1])
-            else:
-                referenced[ref[0]] = set([ref[1]])
+        graph = ConditionDependencyGraph(self, fail_on_undefined_vars)
+
+        results = graph.test_verify_all_dependencies()
+        if verbosity > 0:
+            self.reporter.display_paths(results)
+        return results
 
     def get_container(self, specification):
         """
         Returns an izpack item container filled with specs gathered from the installer
         specified in the constructor.
         """
-        if not self.containers.has_key(specification):
-            return self.init_container(specification)
+        if not specification in self.containers:
+            return self._init_container(specification)
         else:
             return self.containers[specification]
 
@@ -111,7 +110,7 @@ class IzVerifier():
     def find_code_references(self, specification):
         """
         Find all source code references for specs in each container.
-        :param specifications: conditions, variables, strings, or other izpack spec
+        :param specification: conditions, variables, strings, or other izpack spec
         """
         container = self.get_container(specification)
         hits = self.seeker.find_references_in_source(patterns=container.properties[PATTERNS],
@@ -120,31 +119,23 @@ class IzVerifier():
 
         return hits
 
-    def find_spec_references(self, specification):
+    def find_specification_references(self, specification):
         """
         Find all specification xml references for specs in each container.
-        :param installer:
-        :param specifications:
+        :param specification:
         """
         container = self.get_container(specification)
 
         args = {
-             'specs': map(self.paths.get_path, container.properties[REFERENCE_SPEC_FILES]),
-             'filter_fn': container.has_reference,
-             'attributes': container.properties[ATTRIBUTES],
-             'transform_fn': container.ref_transformer,
-             'white_list_patterns': container.properties[WHITE_LIST_PATTERNS]
+            'specs': map(self.paths.get_path, container.properties[REFERENCE_SPEC_FILES]),
+            'filter_fn': container.has_reference,
+            'attributes': container.properties[ATTRIBUTES],
+            'transform_fn': container.ref_transformer,
+            'white_list_patterns': container.properties[WHITE_LIST_PATTERNS]
         }
         hits = self.seeker.search_specs_for_attributes(args)
         return hits
 
-    def dependency_verification(self, verbosity=0, fail_on_undefined_vars=False):
-        """
-        Run a conditions dependency graph search.
-        """
-        results = test_verify_all_dependencies(self, verbosity, fail_on_undefined_vars=fail_on_undefined_vars)
-        return results
-
     def find_references(self, rid, specs=None, verbosity=0):
         """
         Finds all references to the given id in source code and specs file for any of the given specs.
@@ -159,12 +150,12 @@ class IzVerifier():
 
         return results
 
-    def find_reference(self, spec, rid, verbosity=0):
+    def find_reference(self, specification, rid, verbosity=0):
         """
         Find all references to the given id in source and specs for the given spec.
         Returns a set of tuple results.
         """
-        container = self.get_container(spec)
+        container = self.get_container(specification)
 
         props = {
             'path': self.paths.root,
@@ -179,10 +170,32 @@ class IzVerifier():
         }
         results = self.seeker.find_id_references(props)
         if verbosity > 0:
-            self.reporter.report_test('references to {0} in {1}'.format(rid, spec), results)
+            self.reporter.report_test('references to {0} in {1}'.format(rid, specification), results)
         return results
 
-    def fill_classes(self):
+    @staticmethod
+    def _load_references(references, container):
+        """
+        Load a container's referenced map with all detected references from source code and spec files.
+        """
+        referenced = container.get_referenced()
+        for ref in references:
+            if ref[0] in referenced:
+                referenced[ref[0]].add(ref[1])
+            else:
+                referenced[ref[0]] = {ref[1]}
+
+    def _init_container(self, specification):
+        """
+        Initialize a container to be used for verification.
+        """
+        module = importlib.import_module("IzVerifier.izspecs.containers.iz" + specification)
+        class_ = getattr(module, 'Iz' + specification.title())
+        instance = class_(self.paths.get_path(specification))
+        self.containers[specification] = instance
+        return instance
+
+    def _fill_classes(self):
         """
         Fills a 'classes container' with custom class info from source code paths.
         """
@@ -199,28 +212,26 @@ class IzVerifier():
         return self.get_container(specification).get_referenced()
 
 
-def validate_arguments(args):
+def _validate_arguments(args):
     """
     Throws exceptions if required args are missing or invalid.
     """
-    if not args.has_key('specs_path'):
+    if not 'specs_path' in args:
         raise IzArgumentsException("No Path to Installer Specs Specified")
-        exit(1)
-    if not args.has_key('resources_path'):
+    if not 'resources_path' in args:
         raise IzArgumentsException("No Path to Installer Resources Specified")
-        exit(1)
 
 
-def undefined(key_set, tup_set):
+def _undefined(key_set, tup_set):
     """
     Returns the subset of keys from tup_set not present in key_set.
     key_set is a simple set of string keys.
     up_set is a set of tuples: tup[0] is the key of that tuple.
     """
-    return set([tup for tup in tup_set if not quote_remover(tup[0]) in key_set])
+    return set((tup for tup in tup_set if not _quote_remover(tup[0]) in key_set))
 
 
-def unused(key_set, tup_set):
+def _unused(key_set, tup_set):
     """
     Returns the subset of key_set not present in tup_set.
     key_set is a simple set of string keys.
@@ -228,17 +239,16 @@ def unused(key_set, tup_set):
     """
     if not tup_set:
         return key_set
-    return set([key for key in key_set if not key in zip(*tup_set)[0]])
+    return set((key for key in key_set if not key in zip(*tup_set)[0]))
 
 
-def quote_remover(key):
+def _quote_remover(key):
     """
     Extracts the actual key of the item passed in.
-    TODO: seriously do this minus recursion, idiot.
     """
     if key.startswith('"') and key.endswith('"'):
         return key[1:-1]
     if '=' in key:
-        key = quote_remover(''.join(key.split('=')[1:]))
+        key = _quote_remover(''.join(key.split('=')[1:]))
     return key
 
